@@ -15,3 +15,12 @@ from prosuite.parameter import Parameter
 from prosuite.dataset import BaseDataset
 from prosuite.factories.enums import *
 
+class IssueFilters:
+    @classmethod
+    def not_yet_implemented(cls, feature_class: BaseDataset, tolerance: float) -> IssueFilter:
+        """
+        Stay tuned
+        """
+        
+        result = IssueFilter("dummy(0)")
+        return result
\ No newline at end of file
