@@ -1,7 +1,7 @@
 class EnvelopePerimeter:
     """
-    Defines a spatial extent by four coordinates. The spatial reference must match the spatial reference
-    of the datasets.
+    A spatial envelope defined by the bounding coordinates. The spatial reference must match the 
+    spatial reference of the datasets.
     """
     def __init__(self, x_min: float, y_min: float, x_max: float,  y_max: float):
         if x_min is None or x_max is None or y_min is None or y_max is None:
@@ -14,7 +14,7 @@ class EnvelopePerimeter:
 
 class EsriShapePerimeter:
     """
-    The Esri shape buffer format
+    A polygon in the Esri shape buffer format.
     """
     def __init__(self, esri_shape: bytes):
         self.esri_shape = esri_shape
@@ -22,7 +22,8 @@ class EsriShapePerimeter:
 
 class WkbPerimeter:
     """
-    The OGC well-known-binary format
+    A polygon in the OGC well-known-binary format. For example, in ArcPy the geometry's WKB 
+    property could be used to acquire this format.
     """
     def __init__(self, wkb: bytes):
         self.wkb = wkb
\ No newline at end of file
