@@ -23,14 +23,18 @@ MAX_MESSAGE_LENGTH_MB = 1024
 
 class Service:
     """
-    The service class communicates on the grpc channel and executes server functions
+    The service class communicates on the http/2 channel and executes server functions.
 
-    :param host_name: host running the grpc quality verification service
+    :param host_name: The host running the quality verification service
     :type host_name: str
-    :param port_nr: port used for the grpc quality verification service
+    :param port_nr: The port used by the quality verification service
     :type port_nr: int
-    :param channel_credentials: ssl credentials add authentication between client and server and are handled on the channel level
-    :type channel_credentials: str   
+    :param channel_credentials: The ssl credentials and authentication between client and server. 
+        Use :py:meth:`prosuite.utils.get_ssl_channel_credentials` to create the basic https 
+        if the required root certificates are in the windows certificate store.
+        For advanced scenarios or credentials on a non-windows platform, see the gRPC Python docs
+        (https://grpc.github.io/grpc/python/grpc.html).
+    :type channel_credentials: grpc.ChannelCredentials  
     """
 
     ISSUE_GDB = "Issues.gdb"
